@@ -52,9 +52,18 @@ class Apache(object):
         if not os.path.isdir(self.outputdir):
             os.mkdir(self.outputdir)
         opt = self.options.copy()
+
         # turn a list of sslca's into an actual list
         opt['sslca'] = [x.strip() for x in opt.get("sslca", "").strip().split()]
         opt['aliases'] = [x.strip() for x in opt.get('aliases', '').strip().split()]
+
+        # if we have auto-www on, add additional alias:
+        if self.options.get("auto-www", "False") == "True":
+            if opt['sitename'].startswith("www."):
+                opt['aliases'].append(opt['sitename'][4:])
+            else:
+                opt['aliases'].append("www.%s" % opt['sitename'])
+
         template = open(self.options['template']).read()
         cfgfilename = self.options['configfile']
         c = Template(template, searchList = opt)
@@ -67,6 +76,6 @@ class Apache(object):
             pw = htpasswd.HtpasswdFile(self.options['passwdfile'], create=True)
             pw.update(self.options["username"], self.options["password"])
             pw.save()
-        
+
     def update(self):
         pass
